@@ -1,6 +1,7 @@
 # pylint: disable=missing-function-docstring
 # pylint: disable=missing-class-docstring
 # pylint: disable=line-too-long
+# pylint: disable=global-statement
 '''
     A module of utility methods used for generating random data.
 
@@ -31,12 +32,15 @@ import utils.string_utils as _csu
 
 # from utils.dict_utils.dict_utils import get_kwarg as _obj.get_kwarg
 
-
+FAKER_INSTANCE = None
 
 
 
 def faker()->_Faker:
-    return _Faker()
+    global FAKER_INSTANCE
+    if FAKER_INSTANCE is None:
+        FAKER_INSTANCE = _Faker()
+    return FAKER_INSTANCE
 
 
 def gen_variations(value):
@@ -52,7 +56,6 @@ def gen_variations(value):
     varis.append(screaming_snake_case)
     return varis
 
-
 def boolean(bias=50):
     return _random.randint(1,100) <= bias
 
@@ -911,4 +914,8 @@ def user(**kwargs)->dict:
     data['email'] = fake.free_email()
     data['phone'] = fake.phone_number()
 
-    return data
\ No newline at end of file
+    return data
+
+
+
+
