@@ -20,6 +20,7 @@
 
 
 import re as _re
+import json as _json
 import shlex as _shlex
 import sqlparse as _sqlparse
 from typing import Union as _Union
@@ -412,7 +413,7 @@ def _parse_table_column_lines(lines):
     for c in data['columns']:
         c['is_primary_key'] = False
         if c['name'] in data['primary_keys']:
-            c['primary_key'] = True
+            c['is_primary_key'] = True
 
 
 
@@ -448,9 +449,12 @@ def capture_create_table_columns(sql):
     scanner = originalTextFor(nestedExpr('(',')'))
     for match in scanner.searchString(sql):
         val = _csu.strip(match[0],["(",")"])
-        # val = _sql.escape_quoted_chars(val,True,['__%0A__'])
+        val = _sql.escape_quoted_chars(val,True,['__%0A__'])
+        # print(f"val: {val}")
         output = val.split("\n")
-        output = [_sql.escape_quoted_chars(x,True) for x in output]
+        # newlist = [_log(x,"blue") for x in output]
+        # output = [_sql.escape_quoted_chars(x,True) for x in output]
+        # newlist = [_log(x,"yellow") for x in output]
     return output
 
 
@@ -908,6 +912,7 @@ def parse_col_comment(col_data):
         if s.lower().startswith('comment'):
             # _re.replace(r'^comment\s*')
             cmt = s.replace('comment','')
+            cmt = _sql.escape_quoted_chars(cmt,True)
             col_data['comment'] = _csu.strip(cmt,[" "])
             break
 
@@ -1312,8 +1317,9 @@ def get_statements(sql:str):
     if isinstance(sql,(str)):
         if _f.exists(sql):
             raw = _f.readr(sql)
-
+    # @Mstep [] remove single line comments from the sql.
     raw = _sql.strip_comments(raw)
+    # @Mstep [] escape special characters that are within quotes.
     raw = _sql.escape_quoted_chars(raw)
     # raw = format_sql_string(raw)
     statements = [x for x in _sqlparse.parse(raw)]
@@ -1394,9 +1400,13 @@ def parse(sql):
             continue
 
         data['statements'].append(state)
-
-
-
+    # datastring = _json.dumps(data)
+    # data = _json.loads(_sql.escape_quoted_chars(datastring,True))
+    for tb in data['tables']:
+        if 'columns' in tb:
+            for col in tb['columns']:
+                if col['comment'] is not None:
+                    col['comment'] = _sql.escape_quoted_chars(col['comment'],True)
     return data
 
 
